@@ -259,6 +259,7 @@ class SensorGraphPlugin(TileBusProxyPlugin):
         in the ignore list, then it will calculate the checksum.
         Args:
             algorithm (str): The algorithm to hash the data with
+            use_ignorelist (bool): Whether to ignore variables in checksum
         Returns:
             string: The checksum of the config variables
         """
@@ -275,9 +276,12 @@ class SensorGraphPlugin(TileBusProxyPlugin):
             config_desc = self.inspect_config_variable(i)
             config_list.append(config_desc)
 
-            if config_desc.name == ignoreconfigs_list_var:
+            if config_desc.name == ignoreconfigs_list_var and use_ignorelist:
                 ignoreconfigs_bytes = config_desc.data
 
+        # Sort config list first by slot, then variable number
+        config_list = sorted(config_list, key=lambda x: (str(x.target), x.name))
+
         if use_ignorelist:
             ignore_list = _parse_ignoreconfigs(ignoreconfigs_bytes)
             for config in config_list:
